<?php
/**
 * @package   AkeebaLoginGuard
 * @copyright Copyright (c)2016-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\Component\LoginGuard\Administrator\Controller;

defined('_JEXEC') or die;

use Akeeba\Component\LoginGuard\Administrator\Controller\Mixin\ControllerEvents;
use Akeeba\Component\LoginGuard\Administrator\Controller\Mixin\GetRedirectionAware;
use Akeeba\Component\LoginGuard\Administrator\Controller\Mixin\RegisterControllerTasks;
use Akeeba\Component\LoginGuard\Administrator\Controller\Mixin\ReturnURLAware;
use Akeeba\Component\LoginGuard\Administrator\Controller\Mixin\ReusableModels;
use Joomla\CMS\Application\CMSApplication;
use Joomla\CMS\MVC\Controller\AdminController;
use Joomla\CMS\MVC\Factory\MVCFactoryInterface;
use Joomla\Input\Input;

/**
 * Users list controller class.
 *
 * @since  5.0.0
 */
class UsersController extends AdminController
{
	use ControllerEvents;
	use GetRedirectionAware;
	use RegisterControllerTasks;
	use ReturnURLAware;
	use ReusableModels
	{
		ReusableModels::getModel as getModelReusable;
	}

	/**
	 * @var    string  The prefix to use with controller messages.
	 * @since  5.0.0
	 */
	protected $text_prefix = 'COM_USERS_USERS';

	public function __construct($config = [], MVCFactoryInterface $factory = null, ?CMSApplication $app = null, ?Input $input = null)
	{
		parent::__construct($config, $factory, $app, $input);

		// Load com_users' language since we reuse those strings here.
		$jLang = $this->app->getLanguage();
		$jLang->load('com_users');
	}


	/**
	 * Proxy for getModel.
	 *
	 * @param   string   $name     The model name. Optional.
	 * @param   string   $prefix   The class prefix. Optional.
	 * @param   array    $config   Configuration array for model. Optional.
	 *
	 * @return  object  The model.
	 *
	 * @since   5.0.0
	 */
	public function getModel($name = 'Users', $prefix = 'Administrator', $config = ['ignore_request' => true])
	{
		return $this->getModelReusable($name, $prefix, $config);
	}
}
