<?php
/**
 * @package   AkeebaLoginGuard
 * @copyright Copyright (c)2016-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\Component\LoginGuard\Administrator\Event;

defined('_JEXEC') or die;

use Akeeba\Component\LoginGuard\Administrator\DataShape\SetupRenderOptions;
use Akeeba\Component\LoginGuard\Administrator\Event\Backport\ResultAware;
use Akeeba\Component\LoginGuard\Administrator\Event\Backport\ResultAwareInterface;
use Akeeba\Component\LoginGuard\Administrator\Event\Backport\ResultTypeObjectAware;
use Akeeba\Component\LoginGuard\Administrator\Table\TfaTable;
use DomainException;
use Joomla\CMS\Event\AbstractImmutableEvent;

/**
 * Concrete Event class for the onLoginGuardTfaGetSetup event
 *
 * @package     Akeeba\Component\LoginGuard\Administrator\Event
 *
 * @since       6.0.0
 */
class ShowSetup extends AbstractImmutableEvent implements ResultAwareInterface
{
	use ResultAware;
	use ResultTypeObjectAware;

	/** @inheritdoc */
	public function __construct(TfaTable $record)
	{
		parent::__construct('onLoginGuardTfaGetSetup', [
			'record' => $record,
		]);

		$this->resultIsNullable        = true;
		$this->resultAcceptableClasses = [
			SetupRenderOptions::class,
		];
	}

	/**
	 * Validate the value of the 'record' named parameter
	 *
	 * @param   TfaTable  $value
	 *
	 * @return  TfaTable
	 * @since   6.0.0
	 */
	public function setRecord(TfaTable $value): TfaTable
	{
		if (empty($value))
		{
			throw new DomainException(sprintf('Argument \'record\' of event %s must be a TfaTable object', $this->name));
		}

		return $value;
	}
}