<?php
/**
 * @package   AkeebaLoginGuard
 * @copyright Copyright (c)2016-2022 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */


namespace Akeeba\Component\LoginGuard\Site\Service;

defined('_JEXEC') or die;

use Joomla\CMS\Application\SiteApplication;
use Joomla\CMS\Categories\CategoryFactoryInterface;
use Joomla\CMS\Component\Router\RouterView;
use Joomla\CMS\Component\Router\RouterViewConfiguration;
use Joomla\CMS\Component\Router\Rules\MenuRules;
use Joomla\CMS\Component\Router\Rules\NomenuRules;
use Joomla\CMS\Component\Router\Rules\StandardRules;
use Joomla\CMS\Menu\AbstractMenu;
use Joomla\CMS\MVC\Factory\MVCFactory;
use Joomla\CMS\MVC\Factory\MVCFactoryAwareTrait;
use Joomla\CMS\MVC\Model\DatabaseAwareTrait;
use Joomla\Database\DatabaseInterface;

/**
 * SEF router for Akeeba LoginGuard
 *
 * @since  6.0.0
 */
class Router extends RouterView
{
	use MVCFactoryAwareTrait;
	use DatabaseAwareTrait;

	public function __construct(SiteApplication $app, AbstractMenu $menu, DatabaseInterface $db, MVCFactory $factory)
	{
		$this->setDbo($db);
		$this->setMVCFactory($factory);

		$callback = new RouterViewConfiguration('callback');
		$this->registerView($callback);

		$captive = new RouterViewConfiguration('captive');
		$this->registerView($captive);

		$methods = new RouterViewConfiguration('methods');
		$this->registerView($methods);

		$method = new RouterViewConfiguration('method');
		$method->setKey('id');
		$this->registerView($method);


		parent::__construct($app, $menu);

		$this->attachRule(new MenuRules($this));
		$this->attachRule(new StandardRules($this));
		$this->attachRule(new NomenuRules($this));
	}

	public function getMethodId($segment, $query)
	{
		return (int) $segment;
	}

	public function getMethodSegment($id, $query)
	{
		return [$id => (int) $id];
	}
}